/*
 *  Copyright (C) 2004 Crispin Flowerday
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "gul-x11.h"

#include <gdk/gdkx.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xatom.h>

/**
 * gul_x11_get_current_workspace: Get the current workspace
 *
 * Get the currently visible workspace for the #GdkScreen.
 *
 * If the X11 window property isn't found, 0 (the first workspace)
 * is returned.
 */
guint
gul_x11_get_current_workspace (GdkScreen *screen)
{
       GdkWindow *root_win = gdk_screen_get_root_window (screen);
       GdkDisplay *display = gdk_screen_get_display (screen);

       Atom type;
       gint format;
       gulong nitems;
       gulong bytes_after;
       guint *current_desktop;
       guint ret = 0;

       XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (root_win),
                           gdk_x11_get_xatom_by_name_for_display (display, "_NET_CURRENT_DESKTOP"),
                           0, G_MAXLONG,
                           False, XA_CARDINAL, &type, &format, &nitems,
                           &bytes_after, (gpointer)&current_desktop);
       if (type == XA_CARDINAL && format == 32 && nitems > 0)
       {
               ret = current_desktop[0];
               XFree (current_desktop);
       }
       return ret;
}

/**
 * gul_x11_get_window_workspace: Get the workspace the window is on
 *
 * This function gets the workspace that the #GtkWindow is visible on,
 * it returns GUL_X11_ALL_WORKSPACES if the window is sticky, or if
 * the window manager doesn support this function
 */
guint
gul_x11_get_window_workspace (GtkWindow *gtkwindow)
{
       GdkWindow *window = GTK_WIDGET (gtkwindow)->window;
       GdkDisplay *display = gdk_drawable_get_display (window);

       Atom type;
       gint format;
       gulong nitems;
       gulong bytes_after;
       guint *workspace;
       guint ret = GUL_X11_ALL_WORKSPACES;

       XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (window),
                           gdk_x11_get_xatom_by_name_for_display (display, "_NET_WM_DESKTOP"),
                           0, G_MAXLONG,
                           False, XA_CARDINAL, &type, &format, &nitems,
                           &bytes_after, (gpointer)&workspace);
       if (type == XA_CARDINAL && format == 32 && nitems > 0)
       {
               ret = workspace[0];
               XFree (workspace);
       }
       return ret;
}

